@@ -302,13 +302,6 @@ cursor_size_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 	return new_value;
 }
 
-/* Retrieve legacy settings */
-
-static void
-get_legacy_settings (void) 
-{
-}
-
 /* Double Click handling */
 
 struct test_data_t 
@@ -708,7 +701,7 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 		while(folder && (name = g_dir_read_name(folder))) {
 			gchar* cursor_dir = g_strdup_printf("%s/%s/cursors/", fname, name);
 			XcursorImage* cursor;
-			gint sizes[] = { 12, 16, 24, 32, 36, 48, 0 };
+			gint sizes[] = { 12, 16, 24, 32, 36, 40, 48, 64, 0 };
 			gint i;
 
 			if(!g_file_test(cursor_dir, G_FILE_TEST_EXISTS)) {
@@ -920,6 +913,7 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset)
 						     "Name", gtk_cell_renderer_text_new (),
 						     "markup", COLUMN_TEXT,
 						     NULL);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), 1, GTK_SORT_ASCENDING);
 
 	/* Add the cursors */
 	populate_tree_model(GTK_TREE_MODEL_SORT(model), selection);
@@ -982,7 +976,9 @@ create_dialog (void)
 	/* register the custom type */
 	(void) mouse_capplet_check_button_get_type ();
 
-	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/gnome-mouse-properties.glade", "mouse_properties_dialog", NULL);
+	dialog = glade_xml_new (GNOMECC_GLADE_DIR "/gnome-mouse-properties.glade", "mouse_properties_dialog", NULL);
+	if (!dialog)
+		return NULL;
 
 	text = g_strdup_printf ("<b>%s</b>", _("Pointer Theme"));
 	gtk_label_set_markup (GTK_LABEL (WID ("cursor_category_label")), text);
@@ -1024,28 +1020,15 @@ main (int argc, char **argv)
 {
 	GnomeProgram   *program;
 	GConfClient    *client;
-	GConfChangeSet *changeset;
 	GladeXML       *dialog;
 	GtkWidget      *dialog_win;
-	GOptionContext *context;
-
-	static gboolean get_legacy;
-	static GOptionEntry cap_options[] = {
-		{ "get-legacy", 0, 0, G_OPTION_ARG_NONE, &get_legacy,
-		  N_("Retrieve and store legacy settings"), NULL },
-		{ NULL }
-	};
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	context = g_option_context_new (_("- GNOME Mouse Preferences"));
-	g_option_context_add_main_entries (context, cap_options, GETTEXT_PACKAGE);
-
 	program = gnome_program_init ("gnome-mouse-properties", VERSION,
 				      LIBGNOMEUI_MODULE, argc, argv,
-				      GNOME_PARAM_GOPTION_CONTEXT, context,
 				      GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 				      NULL);
 
@@ -1057,16 +1040,14 @@ main (int argc, char **argv)
 	gconf_client_add_dir (client, "/desktop/gnome/peripherals/mouse", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	g_object_unref (client);
 
-	if (get_legacy) {
-		get_legacy_settings ();
-	} else {
-		changeset = NULL;
-		dialog = create_dialog ();
-		setup_dialog (dialog, changeset);
+	dialog = create_dialog ();
+
+	if (dialog) {
+		setup_dialog (dialog, NULL);
 
 		dialog_win = WID ("mouse_properties_dialog");
 		g_signal_connect (dialog_win, "response",
-				  G_CALLBACK (dialog_response_cb), changeset);
+				  G_CALLBACK (dialog_response_cb), NULL);
 
 		capplet_set_icon (dialog_win, "gnome-dev-mouse-optical");
 		gtk_widget_show (dialog_win);
