@@ -162,7 +162,7 @@ create_dialog (void)
 	GladeXML *dialog;
 	GtkWidget *widget, *box, *view;
 
-	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/sound-properties.glade", "sound_prefs_dialog", NULL);
+	dialog = glade_xml_new (GNOMECC_GLADE_DIR "/sound-properties.glade", "sound_prefs_dialog", NULL);
 	widget = glade_xml_get_widget (dialog, "sound_prefs_dialog");
 
 	props = sound_properties_new ();
@@ -441,7 +441,7 @@ device_removed_callback (LibHalContext *ctx, const char *udi)
 }
 
 static void
-setup_hal_devices ()
+setup_hal_devices (void)
 {
 	DBusConnection *connection;
 	DBusError error;
@@ -502,7 +502,7 @@ device_test_button_clicked (GtkWidget *button, gpointer user_data)
 {
 	DeviceChooser *device_chooser = (DeviceChooser *) user_data;
 	
-	GladeXML *dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/sound-properties.glade", NULL, NULL);
+	GladeXML *dialog = glade_xml_new (GNOMECC_GLADE_DIR "/sound-properties.glade", NULL, NULL);
 
 	user_test_pipeline (dialog, GTK_WINDOW (dialog_win), device_chooser->test_pipeline);
 	
@@ -641,7 +641,7 @@ add_selected_device (const gchar *profile, int type)
 }
 
 static void
-setup_devices ()
+setup_devices (void)
 {
 	add_device (AUDIO_PLAYBACK, "autoaudiosink", _("Autodetect"), NULL);
 
@@ -655,8 +655,8 @@ setup_devices ()
 	add_device (AUDIO_CAPTURE, "esdmon", _("ESD - Enlightened Sound Daemon"), NULL);
 	add_device (AUDIO_PLAYBACK, "osssink", _("OSS - Open Sound System"), NULL);
 	add_device (AUDIO_CAPTURE, "osssrc", _("OSS - Open Sound System"), NULL);
-	add_device (AUDIO_PLAYBACK, "polypsink", _("Polypaudio Sound Server"), NULL);
-	add_device (AUDIO_CAPTURE, "polypsrc", _("Polypaudio Sound Server"), NULL);
+	add_device (AUDIO_PLAYBACK, "pulsesink", _("PulseAudio Sound Server"), NULL);
+	add_device (AUDIO_CAPTURE, "pulsesrc", _("PulseAudio Sound Server"), NULL);
 	add_device (AUDIO_CAPTURE, "audiotestsrc wave=triangle is-live=true", _("Test Sound"), NULL);
 	add_device (AUDIO_CAPTURE, "audiotestsrc wave=silence is-live=true", _("Silence"), NULL);
 	
@@ -869,6 +869,7 @@ setup_default_mixer (GladeXML *dialog)
 	g_object_unref (G_OBJECT (model)); 
 
 	renderer = gtk_cell_renderer_text_new ();
+        g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (device_widget), renderer, TRUE);
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (device_widget), renderer,
 			"text", MIXER_DEVICE_MODEL_NAME_COLUMN);
@@ -1019,7 +1020,15 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
- 	context = g_option_context_new (_("- GNOME Sound Preferences"));
+        /* Since gstreamer and gnome-vfs require threads, we
+         * have to initialise threads here as the first call to glib.
+         */
+        g_thread_init (NULL);
+
+ 	context = g_option_context_new (N_("- GNOME Sound Preferences"));
+#if GLIB_CHECK_VERSION (2, 12, 0)
+        g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif
  	g_option_context_add_main_entries (context, cap_options, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gst_init_get_option_group ());
 
